@@ -18,6 +18,7 @@ model_parameters.glimML <- function(model,
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
                                     summary = getOption("parameters_summary", FALSE),
+                                    include_info = getOption("parameters_info", FALSE),
                                     keep = NULL,
                                     drop = NULL,
                                     verbose = TRUE,
@@ -29,6 +30,12 @@ model_parameters.glimML <- function(model,
     merge_by <- "Parameter"
   }
 
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   # dispersion is just an alias...
   if (component == "dispersion") {
     component <- "random"
@@ -46,7 +53,7 @@ model_parameters.glimML <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     verbose = verbose,
     ...
   )
