@@ -41,11 +41,19 @@ model_parameters.averaging <- function(model,
                                        exponentiate = FALSE,
                                        p_adjust = NULL,
                                        summary = getOption("parameters_summary", FALSE),
+                                       include_info = getOption("parameters_info", FALSE),
                                        keep = NULL,
                                        drop = NULL,
                                        verbose = TRUE,
                                        ...) {
   component <- match.arg(component)
+
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -55,7 +63,7 @@ model_parameters.averaging <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     ...
   )
 
