@@ -11,6 +11,7 @@ model_parameters.betareg <- function(model,
                                      exponentiate = FALSE,
                                      p_adjust = NULL,
                                      summary = getOption("parameters_summary", FALSE),
+                                     include_info = getOption("parameters_info", FALSE),
                                      keep = NULL,
                                      drop = NULL,
                                      verbose = TRUE,
@@ -23,6 +24,12 @@ model_parameters.betareg <- function(model,
     verbose = verbose
   )
 
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   component <- match.arg(component)
   if (component == "all") {
     merge_by <- c("Parameter", "Component")
@@ -44,7 +51,7 @@ model_parameters.betareg <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     vcov = NULL,
     vcov_args = NULL
   )
