@@ -11,9 +11,20 @@ model_parameters.mvord <- function(model,
                                    standardize = NULL,
                                    exponentiate = FALSE,
                                    p_adjust = NULL,
+                                   summary = getOption("parameters_summary", FALSE),
+                                   include_info = getOption("parameters_info", FALSE),
+                                   keep = NULL,
+                                   drop = NULL,
                                    verbose = TRUE,
                                    ...) {
   component <- match.arg(component)
+
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -24,6 +35,9 @@ model_parameters.mvord <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    include_info = include_info,
     ...
   )
   attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
@@ -35,7 +49,9 @@ model_parameters.mvord <- function(model,
 standard_error.mvord <- function(model, component = c("all", "conditional", "thresholds", "correlation"), ...) {
   component <- match.arg(component)
   params <- insight::get_parameters(model, component = "all")
-  junk <- utils::capture.output(s <- summary(model))
+  junk <- utils::capture.output({
+    s <- summary(model)
+  })
 
   params$SE <- c(
     unname(s$thresholds[, "Std. Error"]),
@@ -61,7 +77,9 @@ standard_error.mvord <- function(model, component = c("all", "conditional", "thr
 p_value.mvord <- function(model, component = c("all", "conditional", "thresholds", "correlation"), ...) {
   component <- match.arg(component)
   params <- insight::get_parameters(model, component = "all")
-  junk <- utils::capture.output(s <- summary(model))
+  junk <- utils::capture.output({
+    s <- summary(model)
+  })
 
   params$p <- c(
     unname(s$thresholds[, "Pr(>|z|)"]),
