@@ -15,7 +15,7 @@ ci.lme <- function(x,
                    method = "wald",
                    ...) {
   method <- tolower(method)
-  method <- match.arg(method, choices = c("wald", "normal", "residual", "betwithin", "ml1", "satterthwaite"))
+  method <- match.arg(method, choices = c("wald", "normal", "residual", "betwithin", "ml1"))
 
   if (method %in% c("wald", "residual", "normal")) {
     # `vcov` argument must be computed using the `.ci_generic` function.
@@ -49,10 +49,6 @@ ci.lme <- function(x,
     # betwithin approx
   } else if (method == "betwithin") {
     ci_betwithin(x, ci)
-
-    # Satterthwaite
-  } else if (method == "satterthwaite") {
-    ci_satterthwaite(x, ci)
   }
 }
 
@@ -74,8 +70,8 @@ p_value.lme <- function(model,
     se <- standard_error(model, vcov = vcov, vcov_args = vcov_args, ...)
     tstat <- b$Estimate / se$SE
     # residuals are defined like this in `nlme:::summary.lme`
-    df <- model$fixDF[["X"]]
-    p <- 2 * stats::pt(-abs(tstat), df = df)
+    dof <- model$fixDF[["X"]]
+    p <- 2 * stats::pt(-abs(tstat), df = dof)
     param <- se$Parameter
   }
 
@@ -101,9 +97,3 @@ standard_error.gls <- standard_error.default
 
 #' @export
 p_value.gls <- p_value.default
-
-
-#' @export
-degrees_of_freedom.gls <- function(model, method = NULL, ...) {
-  .degrees_of_freedom_no_dfresid_method(model, method)
-}
