@@ -11,6 +11,10 @@ model_parameters.clm2 <- function(model,
                                   standardize = NULL,
                                   exponentiate = FALSE,
                                   p_adjust = NULL,
+                                  summary = getOption("parameters_summary", FALSE),
+                                  include_info = getOption("parameters_info", FALSE),
+                                  keep = NULL,
+                                  drop = NULL,
                                   verbose = TRUE,
                                   ...) {
   component <- match.arg(component)
@@ -20,6 +24,12 @@ model_parameters.clm2 <- function(model,
     merge_by <- "Parameter"
   }
 
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   ## TODO check merge by
 
   out <- .model_parameters_generic(
@@ -32,6 +42,9 @@ model_parameters.clm2 <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    include_info = include_info,
     ...
   )
 
