@@ -8,9 +8,20 @@ model_parameters.selection <- function(model,
                                        standardize = NULL,
                                        exponentiate = FALSE,
                                        p_adjust = NULL,
+                                       summary = getOption("parameters_summary", FALSE),
+                                       include_info = getOption("parameters_info", FALSE),
+                                       keep = NULL,
+                                       drop = NULL,
                                        verbose = TRUE,
                                        ...) {
   component <- match.arg(component)
+
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
@@ -20,6 +31,9 @@ model_parameters.selection <- function(model,
     merge_by = c("Parameter", "Component"),
     standardize = standardize,
     exponentiate = exponentiate,
+    keep_parameters = keep,
+    drop_parameters = drop,
+    include_info = include_info,
     p_adjust = p_adjust,
     ...
   )
@@ -77,9 +91,11 @@ standard_error.selection <- function(model, component = c("all", "selection", "o
 }
 
 
-
 #' @export
-simulate_model.selection <- function(model, iterations = 1000, component = c("all", "selection", "outcome", "auxiliary"), ...) {
+simulate_model.selection <- function(model,
+                                     iterations = 1000,
+                                     component = c("all", "selection", "outcome", "auxiliary"),
+                                     ...) {
   component <- match.arg(component)
   out <- .simulate_model(model, iterations, component = component, effects = "fixed", ...)
 
@@ -91,10 +107,3 @@ simulate_model.selection <- function(model, iterations = 1000, component = c("al
 
 #' @export
 ci.selection <- ci.default
-
-
-#' @export
-degrees_of_freedom.selection <- function(model, ...) {
-  s <- summary(model)
-  s$param$df
-}
