@@ -8,6 +8,7 @@ model_parameters.svyglm <- function(model,
                                     exponentiate = FALSE,
                                     p_adjust = NULL,
                                     summary = getOption("parameters_summary", FALSE),
+                                    include_info = getOption("parameters_info", FALSE),
                                     keep = NULL,
                                     drop = NULL,
                                     verbose = TRUE,
@@ -18,6 +19,12 @@ model_parameters.svyglm <- function(model,
     )
   }
 
+  ## TODO remove deprecated later
+  if (!missing(summary)) {
+    .deprecated_warning("summary", "include_info", verbose)
+    include_info <- summary
+  }
+
   # validation check, warn if unsupported argument is used.
   dot_args <- .check_dots(
     dots = list(...),
@@ -35,7 +42,7 @@ model_parameters.svyglm <- function(model,
     p_adjust = p_adjust,
     keep_parameters = keep,
     drop_parameters = drop,
-    summary = summary,
+    include_info = include_info,
     verbose = verbose
   )
   fun_args <- c(fun_args, dot_args)
