@@ -26,9 +26,9 @@ n_clusters_elbow <- function(x,
   names(out) <- c("n_Clusters", "WSS")
 
   gradient <- c(0, diff(out$WSS))
-  optim <- out$n_Clusters[which.min(gradient)]
+  optimal <- out$n_Clusters[which.min(gradient)]
 
-  attr(out, "n") <- optim
+  attr(out, "n") <- optimal
   attr(out, "gradient") <- gradient
   attr(out, "duration") <- as.numeric(difftime(Sys.time(), t0, units = "secs"))
   class(out) <- c("n_clusters_elbow", class(out))
@@ -75,9 +75,9 @@ n_clusters_gap <- function(x,
   out <- rez[c("clusters", "gap", "SE.sim")]
   names(out) <- c("n_Clusters", "Gap", "SE")
 
-  optim <- cluster::maxSE(f = out$Gap, SE.f = out$SE, method = gap_method)
+  optimal <- cluster::maxSE(f = out$Gap, SE.f = out$SE, method = gap_method)
 
-  attr(out, "n") <- optim
+  attr(out, "n") <- optimal
   attr(out, "ymin") <- rez$ymin
   attr(out, "ymax") <- rez$ymax
   attr(out, "duration") <- as.numeric(difftime(Sys.time(), t0, units = "secs"))
@@ -118,9 +118,9 @@ n_clusters_silhouette <- function(x,
   )
   names(out) <- c("n_Clusters", "Silhouette")
 
-  optim <- which.max(out$Silhouette)
+  optimal <- which.max(out$Silhouette)
 
-  attr(out, "n") <- optim
+  attr(out, "n") <- optimal
   attr(out, "duration") <- as.numeric(difftime(Sys.time(), t0, units = "secs"))
   class(out) <- c("n_clusters_silhouette", class(out))
   out
@@ -149,7 +149,14 @@ n_clusters_silhouette <- function(x,
 #' }
 #' }
 #' @export
-n_clusters_dbscan <- function(x, standardize = TRUE, include_factors = FALSE, method = c("kNN", "SS"), min_size = 0.1, eps_n = 50, eps_range = c(0.1, 3), ...) {
+n_clusters_dbscan <- function(x,
+                              standardize = TRUE,
+                              include_factors = FALSE,
+                              method = c("kNN", "SS"),
+                              min_size = 0.1,
+                              eps_n = 50,
+                              eps_range = c(0.1, 3),
+                              ...) {
   method <- match.arg(method)
   t0 <- Sys.time()
   x <- .prepare_data_clustering(x, include_factors = include_factors, standardize = standardize, ...)
@@ -207,13 +214,31 @@ n_clusters_dbscan <- function(x, standardize = TRUE, include_factors = FALSE, me
 #' }
 #' }
 #' @export
-n_clusters_hclust <- function(x, standardize = TRUE, include_factors = FALSE, distance_method = "correlation", hclust_method = "average", ci = 0.95, iterations = 100, ...) {
+n_clusters_hclust <- function(x,
+                              standardize = TRUE,
+                              include_factors = FALSE,
+                              distance_method = "correlation",
+                              hclust_method = "average",
+                              ci = 0.95,
+                              iterations = 100,
+                              ...) {
   insight::check_if_installed("pvclust")
   t0 <- Sys.time()
-  x <- .prepare_data_clustering(x, include_factors = include_factors, standardize = standardize, ...)
+  x <- .prepare_data_clustering(
+    x,
+    include_factors = include_factors,
+    standardize = standardize,
+    ...
+  )
 
   # pvclust works on columns, so we need to pivot the dataframe
-  model <- pvclust::pvclust(datawizard::data_transpose(x), method.hclust = hclust_method, method.dist = distance_method, nboot = iterations, quiet = TRUE)
+  model <- suppressWarnings(pvclust::pvclust(
+    datawizard::data_transpose(x, verbose = FALSE),
+    method.hclust = hclust_method,
+    method.dist = distance_method,
+    nboot = iterations,
+    quiet = TRUE
+  ))
   out <- .model_parameters_pvclust_clusters(model, x, ci)
 
   attr(out, "model") <- model
@@ -232,7 +257,13 @@ n_clusters_hclust <- function(x, standardize = TRUE, include_factors = FALSE, di
 
 
 #' @keywords internal
-.n_clusters_factoextra <- function(x, method = "wss", standardize = TRUE, include_factors = FALSE, clustering_function = stats::kmeans, n_max = 10, ...) {
+.n_clusters_factoextra <- function(x,
+                                   method = "wss",
+                                   standardize = TRUE,
+                                   include_factors = FALSE,
+                                   clustering_function = stats::kmeans,
+                                   n_max = 10,
+                                   ...) {
   x <- .prepare_data_clustering(x, include_factors = include_factors, standardize = standardize, ...)
 
   insight::check_if_installed("factoextra")
@@ -247,31 +278,31 @@ n_clusters_hclust <- function(x, standardize = TRUE, include_factors = FALSE, di
 
 #' @export
 print.n_clusters_elbow <- function(x, ...) {
-  insight::print_color(paste0("The Elbow method, that aims at minimizing the total intra-cluster variation (i.e., the total within-cluster sum of square), suggests that the optimal number of clusters is ", attributes(x)$n, "."), "green")
+  insight::print_color(paste0("The Elbow method, that aims at minimizing the total intra-cluster variation (i.e., the total within-cluster sum of square), suggests that the optimal number of clusters is ", attributes(x)$n, "."), "green") # nolint
   invisible(x)
 }
 
 #' @export
 print.n_clusters_gap <- function(x, ...) {
-  insight::print_color(paste0("The Gap method, that compares the total intracluster variation of k clusters with their expected values under null reference distribution of the data, suggests that the optimal number of clusters is ", attributes(x)$n, "."), "green")
+  insight::print_color(paste0("The Gap method, that compares the total intracluster variation of k clusters with their expected values under null reference distribution of the data, suggests that the optimal number of clusters is ", attributes(x)$n, "."), "green") # nolint
   invisible(x)
 }
 
 #' @export
 print.n_clusters_silhouette <- function(x, ...) {
-  insight::print_color(paste0("The Silhouette method, based on the average quality of clustering, suggests that the optimal number of clusters is ", attributes(x)$n, "."), "green")
+  insight::print_color(paste0("The Silhouette method, based on the average quality of clustering, suggests that the optimal number of clusters is ", attributes(x)$n, "."), "green") # nolint
   invisible(x)
 }
 
 #' @export
 print.n_clusters_dbscan <- function(x, ...) {
-  insight::print_color(paste0("The DBSCAN method, based on the total clusters sum of squares, suggests that the optimal eps = ", attributes(x)$eps, " (with min. cluster size set to ", attributes(x)$min_size, "), which corresponds to ", attributes(x)$n, " clusters."), "green")
+  insight::print_color(paste0("The DBSCAN method, based on the total clusters sum of squares, suggests that the optimal eps = ", attributes(x)$eps, " (with min. cluster size set to ", attributes(x)$min_size, "), which corresponds to ", attributes(x)$n, " clusters."), "green") # nolint
   invisible(x)
 }
 
 #' @export
 print.n_clusters_hclust <- function(x, ...) {
-  insight::print_color(paste0("The bootstrap analysis of hierachical clustering highlighted ", attributes(x)$n, " significant clusters."), "green")
+  insight::print_color(paste0("The bootstrap analysis of hierachical clustering highlighted ", attributes(x)$n, " significant clusters."), "green") # nolint
   invisible(x)
 }
 
@@ -279,25 +310,28 @@ print.n_clusters_hclust <- function(x, ...) {
 
 #' @export
 visualisation_recipe.n_clusters_elbow <- function(x, ...) {
-  data <- as.data.frame(x)
-  data$Gradient <- datawizard::rescale(attributes(x)$gradient, c(min(data$WSS, max(data$WSS))))
+  input_df <- as.data.frame(x)
+  input_df$Gradient <- datawizard::rescale(
+    attributes(x)$gradient,
+    min(input_df$WSS, max(input_df$WSS))
+  )
   layers <- list()
 
   # Layers -----------------------
   layers[["l1"]] <- list(
     geom = "line",
-    data = data,
+    data = input_df,
     aes = list(x = "n_Clusters", y = "WSS", group = 1),
     size = 1
   )
   layers[["l2"]] <- list(
     geom = "point",
-    data = data,
+    data = input_df,
     aes = list(x = "n_Clusters", y = "WSS")
   )
   layers[["l3"]] <- list(
     geom = "line",
-    data = data,
+    data = input_df,
     aes = list(x = "n_Clusters", y = "Gradient", group = 1),
     size = 0.5,
     color = "red",
@@ -305,7 +339,7 @@ visualisation_recipe.n_clusters_elbow <- function(x, ...) {
   )
   layers[["l4"]] <- list(
     geom = "vline",
-    data = data,
+    data = input_df,
     xintercept = attributes(x)$n,
     linetype = "dotted"
   )
@@ -318,32 +352,32 @@ visualisation_recipe.n_clusters_elbow <- function(x, ...) {
 
   # Out
   class(layers) <- c("visualisation_recipe", "see_visualisation_recipe", class(layers))
-  attr(layers, "data") <- data
+  attr(layers, "data") <- input_df
   layers
 }
 
 
 #' @export
 visualisation_recipe.n_clusters_gap <- function(x, ...) {
-  data <- as.data.frame(x)
-  data$ymin <- attributes(x)$ymin
-  data$ymax <- attributes(x)$ymax
+  dataset <- as.data.frame(x)
+  dataset$ymin <- attributes(x)$ymin
+  dataset$ymax <- attributes(x)$ymax
   layers <- list()
 
   # Layers -----------------------
   layers[["l1"]] <- list(
     geom = "line",
-    data = data,
+    data = dataset,
     aes = list(x = "n_Clusters", y = "Gap", group = 1)
   )
   layers[["l2"]] <- list(
     geom = "pointrange",
-    data = data,
+    data = dataset,
     aes = list(x = "n_Clusters", y = "Gap", ymin = "ymin", ymax = "ymax")
   )
   layers[["l4"]] <- list(
     geom = "vline",
-    data = data,
+    data = dataset,
     xintercept = attributes(x)$n,
     linetype = "dotted"
   )
@@ -356,30 +390,30 @@ visualisation_recipe.n_clusters_gap <- function(x, ...) {
 
   # Out
   class(layers) <- c("visualisation_recipe", "see_visualisation_recipe", class(layers))
-  attr(layers, "data") <- data
+  attr(layers, "data") <- dataset
   layers
 }
 
 
 #' @export
 visualisation_recipe.n_clusters_silhouette <- function(x, ...) {
-  data <- as.data.frame(x)
+  dataset <- as.data.frame(x)
   layers <- list()
 
   # Layers -----------------------
   layers[["l1"]] <- list(
     geom = "line",
-    data = data,
+    data = dataset,
     aes = list(x = "n_Clusters", y = "Silhouette", group = 1)
   )
   layers[["l2"]] <- list(
     geom = "point",
-    data = data,
+    data = dataset,
     aes = list(x = "n_Clusters", y = "Silhouette")
   )
   layers[["l4"]] <- list(
     geom = "vline",
-    data = data,
+    data = dataset,
     xintercept = attributes(x)$n,
     linetype = "dotted"
   )
@@ -392,38 +426,41 @@ visualisation_recipe.n_clusters_silhouette <- function(x, ...) {
 
   # Out
   class(layers) <- c("visualisation_recipe", "see_visualisation_recipe", class(layers))
-  attr(layers, "data") <- data
+  attr(layers, "data") <- dataset
   layers
 }
 
 
 #' @export
 visualisation_recipe.n_clusters_dbscan <- function(x, ...) {
-  data <- as.data.frame(x)
+  dataset <- as.data.frame(x)
 
   layers <- list()
 
 
   # Layers -----------------------
   if ("gradient" %in% names(attributes(x))) {
-    data$gradient <- datawizard::rescale(attributes(x)$gradient, c(min(data$eps), max(data$eps)))
+    dataset$gradient <- datawizard::rescale(
+      attributes(x)$gradient,
+      c(min(dataset$eps), max(dataset$eps))
+    )
 
     layers[["l1"]] <- list(
       geom = "line",
-      data = data,
+      data = dataset,
       aes = list(x = "n_Obs", y = "eps"),
       size = 1
     )
     layers[["l2"]] <- list(
       geom = "line",
-      data = data,
+      data = dataset,
       aes = list(x = "n_Obs", y = "gradient"),
       color = "red",
       linetype = "dashed"
     )
     layers[["l3"]] <- list(
       geom = "hline",
-      data = data,
+      data = dataset,
       yintercept = attributes(x)$eps,
       linetype = "dotted"
     )
@@ -434,24 +471,27 @@ visualisation_recipe.n_clusters_dbscan <- function(x, ...) {
       title = "DBSCAN Method"
     )
   } else {
-    data$y <- datawizard::rescale(data$total_SS, c(min(data$n_Clusters), max(data$n_Clusters)))
+    dataset$y <- datawizard::rescale(
+      dataset$total_SS,
+      c(min(dataset$n_Clusters), max(dataset$n_Clusters))
+    )
 
     layers[["l1"]] <- list(
       geom = "line",
-      data = data,
+      data = dataset,
       aes = list(x = "eps", y = "n_Clusters"),
       size = 1
     )
     layers[["l2"]] <- list(
       geom = "line",
-      data = data,
+      data = dataset,
       aes = list(x = "eps", y = "y"),
       color = "red",
       linetype = "dashed"
     )
     layers[["l3"]] <- list(
       geom = "vline",
-      data = data,
+      data = dataset,
       xintercept = attributes(x)$eps,
       linetype = "dotted"
     )
@@ -465,7 +505,7 @@ visualisation_recipe.n_clusters_dbscan <- function(x, ...) {
 
   # Out
   class(layers) <- c("visualisation_recipe", "see_visualisation_recipe", class(layers))
-  attr(layers, "data") <- data
+  attr(layers, "data") <- dataset
   layers
 }
 
@@ -487,6 +527,6 @@ plot.n_clusters_dbscan <- plot.n_clusters_elbow
 #' @export
 plot.n_clusters_hclust <- function(x, ...) {
   insight::check_if_installed("pvclust")
-  graphics::plot(attributes(x)$model)
-  pvclust::pvrect(attributes(x)$model, alpha = attributes(x)$ci, pv = "si")
+  graphics::plot(attributes(x)[["model"]])
+  pvclust::pvrect(attributes(x)[["model"]], alpha = attributes(x)$ci, pv = "si")
 }
