@@ -17,12 +17,10 @@
 #'
 #' @note
 #' Models with multiple components, (for instance, models with zero-inflation,
-#' where predictors appear in the count and zero-inflation part) may fail in
-#' case of identical names for coefficients in the different model components,
-#' since the coefficient table is grouped by coefficient names for pooling. In
-#' such cases, coefficients of count and zero-inflation model parts would be
-#' combined. Therefore, the `component` argument defaults to
-#' `"conditional"` to avoid this.
+#' where predictors appear in the count and zero-inflation part, or models with
+#' dispersion component) may fail in rare situations. In this case, compute
+#' the pooled parameters for components separately, using the `component`
+#' argument.
 #'
 #' Some model objects do not return standard errors (e.g. objects of class
 #' `htest`). For these models, no pooled confidence intervals nor p-values
@@ -68,7 +66,7 @@
 pool_parameters <- function(x,
                             exponentiate = FALSE,
                             effects = "fixed",
-                            component = "conditional",
+                            component = "all",
                             verbose = TRUE,
                             ...) {
   # check input, save original model -----
@@ -163,75 +161,92 @@ pool_parameters <- function(x,
     params <- params[params$Effects != "random", ]
     parameter_values <- x[[1]]$Parameter[x[[1]]$Effects != "random"]
   }
-  estimates <- split(params, factor(params$Parameter, levels = unique(parameter_values)))
 
+  # split by component
+  if (!is.null(params$Component) && insight::n_unique(params$Component) > 1) {
+    component_values <- x[[1]]$Component
+    estimates <- split(
+      params,
+      list(
+        factor(params$Parameter, levels = unique(parameter_values)),
+        factor(params$Component, levels = unique(component_values))
+      )
+    )
+  } else {
+    component_values <- NULL
+    estimates <- split(
+      params,
+      factor(params$Parameter, levels = unique(parameter_values))
+    )
+  }
 
   # pool estimates etc. -----
 
   pooled_params <- do.call(rbind, lapply(estimates, function(i) {
-    # pooled estimate
-    pooled_estimate <- mean(i$Coefficient)
+    # if we split by "component", some of the data frames might be empty
+    # in this case, just skip...
+    if (nrow(i) > 0) {
+      # pooled estimate
+      pooled_estimate <- mean(i$Coefficient)
 
-    # special models that have no standard errors (like "htest" objects)
-    if (is.null(i$SE) || all(is.na(i$SE))) {
-      out <- data.frame(
-        Coefficient = pooled_estimate,
-        SE = NA,
-        CI_low = NA,
-        CI_high = NA,
-        Statistic = NA,
-        df_error = NA,
-        p = NA,
-        stringsAsFactors = FALSE
-      )
+      # special models that have no standard errors (like "htest" objects)
+      if (is.null(i$SE) || all(is.na(i$SE))) {
+        out <- data.frame(
+          Coefficient = pooled_estimate,
+          SE = NA,
+          CI_low = NA,
+          CI_high = NA,
+          Statistic = NA,
+          df_error = NA,
+          p = NA,
+          stringsAsFactors = FALSE
+        )
 
-      if (verbose) {
-        insight::format_alert("Model objects had no standard errors. Cannot compute pooled confidence intervals and p-values.")
-      }
-
-      # regular models that have coefficients and standard errors
-    } else {
-      # pooled standard error
-      ubar <- mean(i$SE^2)
-      tmp <- ubar + (1 + 1 / len) * stats::var(i$Coefficient)
-      pooled_se <- sqrt(tmp)
-
-      # pooled degrees of freedom, Barnard-Rubin adjustment for small samples
-      df_column <- grep("(\\bdf\\b|\\bdf_error\\b)", colnames(i), value = TRUE)[1]
-      if (length(df_column)) {
-        pooled_df <- .barnad_rubin(m = nrow(i), b = stats::var(i$Coefficient), t = tmp, dfcom = unique(i[[df_column]]))
-        # validation check length
-        if (length(pooled_df) > 1 && length(pooled_se) == 1) {
-          pooled_df <- round(mean(pooled_df, na.rm = TRUE))
+        if (verbose) {
+          insight::format_alert("Model objects had no standard errors. Cannot compute pooled confidence intervals and p-values.")
         }
+
+        # regular models that have coefficients and standard errors
       } else {
-        pooled_df <- Inf
+        # pooled standard error
+        ubar <- mean(i$SE^2)
+        tmp <- ubar + (1 + 1 / len) * stats::var(i$Coefficient)
+        pooled_se <- sqrt(tmp)
+
+        # pooled degrees of freedom, Barnard-Rubin adjustment for small samples
+        df_column <- grep("(\\bdf\\b|\\bdf_error\\b)", colnames(i), value = TRUE)[1]
+        if (length(df_column)) {
+          pooled_df <- .barnad_rubin(m = nrow(i), b = stats::var(i$Coefficient), t = tmp, dfcom = unique(i[[df_column]]))
+          # validation check length
+          if (length(pooled_df) > 1 && length(pooled_se) == 1) {
+            pooled_df <- round(mean(pooled_df, na.rm = TRUE))
+          }
+        } else {
+          pooled_df <- Inf
+        }
+
+        # pooled statistic
+        pooled_statistic <- pooled_estimate / pooled_se
+
+        # confidence intervals
+        alpha <- (1 + ci) / 2
+        fac <- suppressWarnings(stats::qt(alpha, df = pooled_df))
+
+        out <- data.frame(
+          Coefficient = pooled_estimate,
+          SE = pooled_se,
+          CI_low = pooled_estimate - pooled_se * fac,
+          CI_high = pooled_estimate + pooled_se * fac,
+          Statistic = pooled_statistic,
+          df_error = pooled_df,
+          p = 2 * stats::pt(abs(pooled_statistic), df = pooled_df, lower.tail = FALSE),
+          stringsAsFactors = FALSE
+        )
       }
-
-      # pooled statistic
-      pooled_statistic <- pooled_estimate / pooled_se
-
-      # confidence intervals
-      alpha <- (1 + ci) / 2
-      fac <- suppressWarnings(stats::qt(alpha, df = pooled_df))
-
-      out <- data.frame(
-        Coefficient = pooled_estimate,
-        SE = pooled_se,
-        CI_low = pooled_estimate - pooled_se * fac,
-        CI_high = pooled_estimate + pooled_se * fac,
-        Statistic = pooled_statistic,
-        df_error = pooled_df,
-        p = 2 * stats::pt(abs(pooled_statistic), df = pooled_df, lower.tail = FALSE),
-        stringsAsFactors = FALSE
-      )
+      out
+    } else {
+      NULL
     }
-
-    # add component, when pooling for all components
-    if (identical(component, "all") && "Component" %in% colnames(i)) {
-      out$Component <- i$Component[1]
-    }
-    out
   }))
 
 
@@ -249,13 +264,13 @@ pool_parameters <- function(x,
         stringsAsFactors = FALSE
       )
     }))
+    pooled_params$Effects <- "fixed"
   }
 
-
   # reorder ------
 
   pooled_params$Parameter <- parameter_values
-  columns <- c("Parameter", "Coefficient", "SE", "CI_low", "CI_high", "Statistic", "df_error", "p", "Component")
+  columns <- c("Parameter", "Coefficient", "SE", "CI_low", "CI_high", "Statistic", "df_error", "p", "Effects", "Component")
   pooled_params <- pooled_params[intersect(columns, colnames(pooled_params))]
 
 
@@ -268,6 +283,11 @@ pool_parameters <- function(x,
     pooled_params <- merge(pooled_params, pooled_random, all = TRUE, sort = FALSE)
   }
 
+  # add back component column
+  if (!is.null(component_values)) {
+    pooled_params$Component <- component_values
+  }
+
   # this needs to be done extra here, cannot call ".add_model_parameters_attributes()"
   pooled_params <- .add_pooled_params_attributes(
     pooled_params,
