@@ -1,6 +1,6 @@
 # normal print ----------------------------
 
-#' @rdname display.parameters_model
+#' @rdname print.parameters_model
 #' @export
 print_html.parameters_model <- function(x,
                                         pretty_names = TRUE,
@@ -138,6 +138,7 @@ print_html.parameters_simulate <- print_html.parameters_model
 #' @export
 print_html.parameters_sem <- print_html.parameters_model
 
+#' @rdname print.compare_parameters
 #' @export
 print_html.compare_parameters <- function(x,
                                           caption = NULL,
@@ -213,6 +214,12 @@ print_html.compare_parameters <- function(x,
     groups = groups
   )
 
+  # replace brackets by parenthesis
+  if (!is.null(ci_brackets) && "Parameter" %in% colnames(formatted_table)) {
+    formatted_table$Parameter <- gsub("[", ci_brackets[1], formatted_table$Parameter, fixed = TRUE)
+    formatted_table$Parameter <- gsub("]", ci_brackets[2], formatted_table$Parameter, fixed = TRUE)
+  }
+
   out <- insight::export_table(
     formatted_table,
     format = "html",
