@@ -295,15 +295,15 @@
   }
 
   # fix coefficient column name for random effects
-  if (!is.null(x$Effects) && all(x$Effects == "random") && any(colnames(x) %in% .all_coefficient_types())) {
-    colnames(x)[colnames(x) %in% .all_coefficient_types()] <- "Coefficient"
+  if (!is.null(x$Effects) && all(x$Effects == "random") && any(colnames(x) %in% .all_coefficient_types)) {
+    colnames(x)[colnames(x) %in% .all_coefficient_types] <- "Coefficient"
   }
 
   # fix coefficient column name for mixed count and zi pars
   if (!is.null(x$Component) &&
     sum(c("conditional", "zero_inflated", "dispersion") %in% x$Component) >= 2 &&
-    any(colnames(x) %in% .all_coefficient_types())) {
-    colnames(x)[colnames(x) %in% .all_coefficient_types()] <- "Coefficient"
+    any(colnames(x) %in% .all_coefficient_types)) {
+    colnames(x)[colnames(x) %in% .all_coefficient_types] <- "Coefficient"
   }
 
   # random pars with level? combine into parameter column
@@ -371,13 +371,31 @@
 
   # check if we have model data, else return parameter table
   if (is.null(model_data)) {
-    params
+    return(params)
   }
 
   # find factors and factor levels and check if we have any factors in the data
   factors <- .find_factor_levels(model_data, model, model_call = attributes(params)$model_call)
   if (!length(factors)) {
-    params
+    # in case of "on-the-fly" factors, e.g.:
+    # m <- lm(mpg ~ cut(wt, c(0, 2.5, 3, 5)), data = mtcars)
+    # we need to receive the data from the model frame, in order to find factors
+    model_data <- insight::get_data(model, source = "mf", verbose = FALSE)
+    if (!is.null(model_data)) {
+      factors <- .find_factor_levels(model_data, model, model_call = attributes(params)$model_call)
+    }
+    # if we still didn't find anything, quit...
+    if (!length(factors)) {
+      return(params)
+    }
+  }
+  # next, check contrasts of factors. including the reference level makes
+  # only sense if there are contrasts that are all zeros, which means that
+  # the reference level is not included in the model matrix
+  remove_contrasts <- .remove_reference_contrasts(model)
+  # keep only factors with valid contrasts
+  if (!is.null(remove_contrasts) && length(remove_contrasts)) {
+    factors <- factors[setdiff(names(factors), remove_contrasts)]
   }
 
   # we need some more information about prettified labels etc.
@@ -430,6 +448,19 @@
       }
       # create a pretty level for the reference category
       pretty_level <- paste0(fn_clean, " [", sub(fn, "", reference_level, fixed = TRUE), "]")
+      pretty_level <- gsub("_", " ", pretty_level, fixed = TRUE)
+      # special handling for "cut()"
+      pattern_cut_right <- "(.*)\\((.*),(.*)\\]\\]$"
+      pattern_cut_left <- "(.*)\\[(.*),(.*)\\)\\]$"
+      if (all(grepl(pattern_cut_right, pretty_level))) {
+        lower_bounds <- gsub(pattern_cut_right, "\\2", pretty_level)
+        upper_bounds <- gsub(pattern_cut_right, "\\3", pretty_level)
+        pretty_level <- gsub(pattern_cut_right, paste0("\\1>", as.numeric(lower_bounds), "-", upper_bounds, "]"), pretty_level)
+      } else if (all(grepl(pattern_cut_left, pretty_level))) {
+        lower_bounds <- gsub(pattern_cut_left, "\\2", pretty_level)
+        upper_bounds <- gsub(pattern_cut_left, "\\3", pretty_level)
+        pretty_level <- gsub(pattern_cut_left, paste0("\\1", as.numeric(lower_bounds), "-<", upper_bounds, "]"), pretty_level)
+      }
       # insert new pretty level at the correct position in "pretty_names"
       pretty_names <- .insert_element_at(
         pretty_names,
@@ -468,13 +499,14 @@
 # components into different tables, we change the column name for those "tables"
 # that contain the random effects or zero-inflation parameters
 
-.all_coefficient_types <- function() {
-  c(
-    "Odds Ratio", "Risk Ratio", "Prevalence Ratio", "IRR", "Log-Odds",
-    "Log-Mean", "Log-Ratio", "Log-Prevalence", "Probability", "Marginal Means",
-    "Estimated Counts", "Ratio"
-  )
-}
+.all_coefficient_types <- c(
+  "Odds Ratio", "Risk Ratio", "Prevalence Ratio", "IRR", "Log-Odds",
+  "Log-Mean", "Log-Ratio", "Log-Prevalence", "Probability", "Marginal Means",
+  "Estimated Counts", "Ratio"
+)
+
+
+.all_coefficient_names <- c("Coefficient", "Std_Coefficient", "Estimate", "Median", "Mean", "MAP")
 
 
 .format_stan_parameters <- function(out) {
@@ -1087,8 +1119,8 @@
     }
 
     # rename columns for random part
-    if (grepl("random", type, fixed = TRUE) && any(colnames(tables[[type]]) %in% .all_coefficient_types())) {
-      colnames(tables[[type]])[colnames(tables[[type]]) %in% .all_coefficient_types()] <- "Coefficient"
+    if (grepl("random", type, fixed = TRUE) && any(colnames(tables[[type]]) %in% .all_coefficient_types)) {
+      colnames(tables[[type]])[colnames(tables[[type]]) %in% .all_coefficient_types] <- "Coefficient"
     }
 
     if (grepl("random", type, fixed = TRUE) && isTRUE(ran_pars)) {
