@@ -10,7 +10,7 @@
                                              iterations = 1000,
                                              ci_method = NULL,
                                              p_adjust = NULL,
-                                             summary = FALSE,
+                                             include_info = FALSE,
                                              verbose = TRUE,
                                              group_level = FALSE,
                                              wb_component = FALSE,
@@ -54,13 +54,10 @@
   attr(params, "robust_vcov") <- isTRUE(list(...)$robust) || "vcov" %in% names(list(...))
   attr(params, "ignore_group") <- isFALSE(group_level)
   attr(params, "ran_pars") <- isFALSE(group_level)
-  attr(params, "show_summary") <- isTRUE(summary)
+  attr(params, "show_summary") <- isTRUE(include_info)
   attr(params, "log_link") <- isTRUE(grepl("log", info$link_function, fixed = TRUE))
   attr(params, "logit_link") <- isTRUE(identical(info$link_function, "logit"))
 
-  # add parameters with value and variable
-  attr(params, "pretty_labels") <- .format_value_labels(params, model)
-
   # save model call
   attr(params, "model_call") <- .safe(insight::get_call(model))
 
@@ -80,10 +77,12 @@
   }
 
 
-  # for summaries, add R2
-  if (isTRUE(summary) && requireNamespace("performance", quietly = TRUE)) {
+  # for additional infos, add R2, RMSE
+  if (isTRUE(include_info) && requireNamespace("performance", quietly = TRUE)) {
     rsq <- .safe(suppressWarnings(performance::r2(model)))
     attr(params, "r2") <- rsq
+    rmse <- .safe(performance::performance_rmse(model))
+    attr(params, "rmse") <- rmse
   }
 
 
@@ -101,7 +100,7 @@
 
   # weighted nobs
   weighted_nobs <- .safe({
-    w <- insight::get_weights(model, na_rm = TRUE, null_as_ones = TRUE)
+    w <- insight::get_weights(model, remove_na = TRUE, null_as_ones = TRUE)
     round(sum(w))
   })
   attr(params, "weighted_nobs") <- weighted_nobs
@@ -208,6 +207,9 @@
     attributes(params) <- utils::modifyList(a, attributes(params))
   }
 
+  # add parameters with value and variable
+  attr(params, "pretty_labels") <- .format_value_labels(params, model)
+
   row.names(params) <- NULL
   params
 }
