@@ -1,17 +1,15 @@
-requiet("lme4")
-
-data(mtcars)
-
 test_that("ci", {
+  skip_if_not_installed("lme4")
+
   model <- lm(mpg ~ wt, data = mtcars)
-  expect_equal(ci(model)[1, 3], 33.4505, tolerance = 0.01)
-  expect_equal(ci(model, ci = c(0.7, 0.8))[1, 3], 35.30486, tolerance = 0.01)
+  expect_equal(suppressMessages(ci(model))[1, 3], 33.4505, tolerance = 0.01)
+  expect_equal(suppressMessages(ci(model, ci = c(0.7, 0.8)))[1, 3], 35.30486, tolerance = 0.01)
 
   model <- glm(vs ~ wt, family = "binomial", data = mtcars)
-  expect_equal(ci(model)[1, 3], 1.934013, tolerance = 0.01)
+  expect_equal(suppressMessages(ci(model))[1, 3], 1.934013, tolerance = 0.01)
 
   model <- lme4::lmer(wt ~ cyl + (1 | gear), data = mtcars)
-  expect_equal(ci(model, method = "normal")[1, 3], -0.335063, tolerance = 0.01)
+  expect_equal(suppressMessages(ci(model, method = "normal"))[1, 3], -0.335063, tolerance = 0.01)
 
   model <- lme4::lmer(wt ~ cyl + (1 | gear), data = mtcars)
   expect_equal(ci(model)[1, 3], -0.3795646, tolerance = 0.01)
@@ -29,20 +27,22 @@ test_that("ci", {
 
 
 test_that("vs. sandwich & lmtest", {
-  requiet("sandwich")
-  requiet("lmtest")
+  skip_if_not_installed("sandwich")
+  skip_if_not_installed("lmtest")
 
   model <- lm(mpg ~ wt, data = mtcars)
-  known <- coefci(model, vcov = vcovHC)
-  unknown <- ci(model, vcov = vcovHC)
+  known <- lmtest::coefci(model, vcov = sandwich::vcovHC)
+  unknown <- ci(model, vcov = sandwich::vcovHC)
   expect_equal(unknown[["CI_low"]], known[, "2.5 %"], ignore_attr = TRUE)
   expect_equal(unknown[["CI_high"]], known[, "97.5 %"], ignore_attr = TRUE)
 
   model <- glm(am ~ wt, data = mtcars, family = binomial)
-  known <- coefci(model, vcov = vcovHC)
-  unknown <- ci(model, vcov = vcovHC, method = "wald")
+  known <- lmtest::coefci(model, vcov = sandwich::vcovHC)
+  unknown <- ci(model, vcov = sandwich::vcovHC, method = "wald")
   expect_equal(unknown[["CI_low"]], known[, "2.5 %"], ignore_attr = TRUE)
   expect_equal(unknown[["CI_high"]], known[, "97.5 %"], ignore_attr = TRUE)
 
-  expect_warning(ci(model, vcov = vcovHC), regexp = "vcov.*are not available with.*profile")
+  suppressMessages(
+    expect_message(ci(model, vcov = sandwich::vcovHC), regexp = "vcov.*are not available with.*profile")
+  )
 })
